summaryrefslogtreecommitdiff
path: root/tinyusb
diff options
context:
space:
mode:
Diffstat (limited to 'tinyusb')
-rw-r--r--tinyusb/host/usbh.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tinyusb/host/usbh.c b/tinyusb/host/usbh.c
index 333d2d9a2..a8a9aa3b6 100644
--- a/tinyusb/host/usbh.c
+++ b/tinyusb/host/usbh.c
@@ -289,8 +289,8 @@ tusb_error_t enumeration_body_subtask(void)
usbh_devices[0].state = TUSB_DEVICE_STATE_ADDRESSED;
#ifndef _TEST_
- // TODO hack delay 100 ms for slow device (use retry on the 1st xfer instead later)
- osal_task_delay(100);
+ // TODO hack delay 20 ms for slow device (use retry on the 1st xfer instead later)
+ osal_task_delay(20);
#endif
//------------- Get first 8 bytes of device descriptor to get Control Endpoint Size -------------//